Cancel a download creation process.
occ_download_cancel(
key,
user = NULL,
pwd = NULL,
curlopts = list(http_version = 2)
)occ_download_cancel_staged(
user = NULL,
pwd = NULL,
limit = 20,
start = 0,
curlopts = list(http_version = 2)
)
(character) A key generated from a request, like that from
occ_download. Required.
(character) User name within GBIF's website. Required. See Details.
(character) User password within GBIF's website. Required. See Details.
list of named curl options passed on to
HttpClient. see curl::curl_options
for curl options
Number of records to return. Default: 20
Record number to start at. Default: 0
Note, these functions only cancel a job in progress. If your download is already prepared for you, this won't do anything to change that.
occ_download_cancel cancels a specific job by download key - returns
success message
occ_download_cancel_staged cancels all jobs with status RUNNING
or PREPARING - if none are found, returns a message saying so -
if some found, they are cancelled, returning message saying so
Other downloads:
download_predicate_dsl,
occ_download_cached(),
occ_download_dataset_activity(),
occ_download_datasets(),
occ_download_get(),
occ_download_import(),
occ_download_list(),
occ_download_meta(),
occ_download_queue(),
occ_download_stats_dataset_records(),
occ_download_stats_dataset(),
occ_download_stats_export(),
occ_download_stats_source(),
occ_download_stats_user_country(),
occ_download_stats(),
occ_download_wait(),
occ_download()
if (FALSE) {
# occ_download_cancel(key="0003984-140910143529206")
# occ_download_cancel_staged()
}
Run the code above in your browser using DataLab