Skip to contents

Summarize downloads by dataset.

Usage

occ_download_stats_dataset(
  from = NULL,
  to = NULL,
  publishingCountry = NULL,
  datasetKey = NULL,
  publishingOrgKey = NULL,
  curlopts = list(http_version = 2)
)

Arguments

from

(character) Start date in format YYYY-MM. Optional.

to

(character) End date in format YYYY-MM. Optional.

publishingCountry

(character) ISO 2-letter country code. Optional.

datasetKey

(character) Dataset UUID. Optional.

publishingOrgKey

(character) Publishing organization UUID. Optional.

curlopts

list of named curl options passed on to crul::HttpClient. See curl::curl_options for curl options

Value

A tibble with columns: year, month, number_downloads. Each row represents the total number of downloads for a given year and month.

Note

see downloads for an overview of GBIF downloads methods

Examples

if (FALSE) { # \dontrun{
# Get downloads by dataset
occ_download_stats_dataset()

# Filter by date range and publishing country
occ_download_stats_dataset(from = "2023-01", publishingCountry = "US")

# Filter by publishing organization (e.g., iNaturalist)
occ_download_stats_dataset(publishingOrgKey = "28eb1a3f-1c15-4a95-931a-4af90ecb574d")
} # }