Skip to contents

Summarize downloaded records by dataset.

Usage

occ_download_stats_dataset_records(
  from = NULL,
  to = NULL,
  publishingCountry = NULL,
  datasetKey = NULL,
  publishingOrgKey = NULL,
  curlopts = list(http_version = 2)
)

Arguments

from

(character) Start date in format YYYY-MM. Optional.

to

(character) End date in format YYYY-MM. Optional.

publishingCountry

(character) ISO 2-letter country code. Optional.

datasetKey

(character) Dataset UUID. Optional.

publishingOrgKey

(character) Publishing organization UUID. Optional.

curlopts

list of named curl options passed on to crul::HttpClient. See curl::curl_options for curl options

Value

A tibble with columns: year, month, number_records. Each row represents the total number of records downloaded for a given year and month.

Note

see downloads for an overview of GBIF downloads methods

Examples

if (FALSE) { # \dontrun{
# Get downloaded records by dataset
occ_download_stats_dataset_records()

# Filter by date range
occ_download_stats_dataset_records(from = "2023-01", to = "2023-12")

# Filter by specific dataset
occ_download_stats_dataset_records(
  datasetKey = "50c9509d-22c7-4a22-a47d-8c48425ef4a7"
)
} # }