Skip to contents

Summarize downloads by source.

Usage

occ_download_stats_source(
  from = NULL,
  to = NULL,
  source = NULL,
  curlopts = list(http_version = 2)
)

Arguments

from

(character) Start date in format YYYY-MM. Optional.

to

(character) End date in format YYYY-MM. Optional.

source

(character) Restrict to a particular source (e.g., "rgbif", "pygbif"). Optional.

curlopts

list of named curl options passed on to crul::HttpClient. See curl::curl_options for curl options

Value

A tibble with columns: year, month, number_downloads. Each row represents the total number of downloads for a given year and month.

Note

see downloads for an overview of GBIF downloads methods

Examples

if (FALSE) { # \dontrun{
# Get downloads by source
occ_download_stats_source()

# Filter by date range
occ_download_stats_source(from = "2023-01", to = "2023-12")

# Filter by source
occ_download_stats_source(source = "pygbif")
} # }