Skip to contents

Summarizes downloads by month, grouped by the user's country code.

Usage

occ_download_stats_user_country(
  from = NULL,
  to = NULL,
  userCountry = NULL,
  publishingCountry = NULL,
  curlopts = list(http_version = 2)
)

Arguments

from

(character) Start date in format YYYY-MM. Optional.

to

(character) End date in format YYYY-MM. Optional.

userCountry

(character) ISO 2-letter country code. Optional.

publishingCountry

(character) ISO 2-letter country code. Optional.

curlopts

list of named curl options passed on to crul::HttpClient. See curl::curl_options for curl options

Value

A tibble with download counts by user country and month

Note

see downloads for an overview of GBIF downloads methods

Examples

if (FALSE) { # \dontrun{
# Run with no args to get monthly download counts for all of GBIF 
occ_download_stats_user_country()

# Filter by date range
occ_download_stats_user_country(from = "2023-01", to = "2023-12")

# Filter by user country
occ_download_stats_user_country(userCountry = "US")
} # }