name_suggest: A quick and simple autocomplete service that returns up to 20 name usages by
doing prefix matching against the scientific name. Results are ordered by relevance.
Description
A quick and simple autocomplete service that returns up to 20 name usages by
doing prefix matching against the scientific name. Results are ordered by relevance.
Pass on options to httr::GET for more refined control of
http calls, and error handling
limit
Number of records to return
start
Record number to start at
q
(character, required) Simple search parameter. The value for this parameter can be a
simple word or a phrase. Wildcards can be added to the simple word parameters only,
e.g. q=*puma*
datasetKey
(character) Filters by the checklist dataset key (a uuid, see examples)
rank
(character) The rank given as our rank enum.
fields
(character) Fields to return in output data.frame (simply prunes columns off)