Summarize downloaded records by dataset.
Usage
occ_download_stats_dataset_records(
from = NULL,
to = NULL,
publishingCountry = NULL,
datasetKey = NULL,
publishingOrgKey = NULL,
curlopts = list(http_version = 2)
)Arguments
- from
(character) Start date in format
YYYY-MM. Optional.- to
(character) End date in format
YYYY-MM. Optional.- publishingCountry
(character) ISO 2-letter country code. Optional.
- datasetKey
(character) Dataset UUID. Optional.
- publishingOrgKey
(character) Publishing organization UUID. Optional.
- curlopts
list of named curl options passed on to crul::HttpClient. See curl::curl_options for curl options
Value
A tibble with columns: year, month, number_records. Each row
represents the total number of records downloaded for a given year and month.
Note
see downloads for an overview of GBIF downloads methods
See also
Other downloads:
download_predicate_dsl,
occ_download_cached(),
occ_download_cancel(),
occ_download_dataset_activity(),
occ_download_datasets(),
occ_download_get(),
occ_download_import(),
occ_download_list(),
occ_download_meta(),
occ_download_queue(),
occ_download_stats_dataset(),
occ_download_stats_export(),
occ_download_stats_source(),
occ_download_stats_user_country(),
occ_download_stats(),
occ_download_wait(),
occ_download()
Examples
if (FALSE) { # \dontrun{
# Get downloaded records by dataset
occ_download_stats_dataset_records()
# Filter by date range
occ_download_stats_dataset_records(from = "2023-01", to = "2023-12")
# Filter by specific dataset
occ_download_stats_dataset_records(
datasetKey = "50c9509d-22c7-4a22-a47d-8c48425ef4a7"
)
} # }