Summarizes downloads by month, grouped by the user's country code.
Usage
occ_download_stats_user_country(
from = NULL,
to = NULL,
userCountry = NULL,
publishingCountry = NULL,
curlopts = list(http_version = 2)
)Arguments
- from
(character) Start date in format
YYYY-MM. Optional.- to
(character) End date in format
YYYY-MM. Optional.- userCountry
(character) ISO 2-letter country code. Optional.
- publishingCountry
(character) ISO 2-letter country code. Optional.
- curlopts
list of named curl options passed on to crul::HttpClient. See curl::curl_options for curl options
Note
see downloads for an overview of GBIF downloads methods
See also
Other downloads:
download_predicate_dsl,
occ_download_cached(),
occ_download_cancel(),
occ_download_dataset_activity(),
occ_download_datasets(),
occ_download_get(),
occ_download_import(),
occ_download_list(),
occ_download_meta(),
occ_download_queue(),
occ_download_stats_dataset_records(),
occ_download_stats_dataset(),
occ_download_stats_export(),
occ_download_stats_source(),
occ_download_stats(),
occ_download_wait(),
occ_download()
Examples
if (FALSE) { # \dontrun{
# Run with no args to get monthly download counts for all of GBIF
occ_download_stats_user_country()
# Filter by date range
occ_download_stats_user_country(from = "2023-01", to = "2023-12")
# Filter by user country
occ_download_stats_user_country(userCountry = "US")
} # }