Count downloads for a user.
Usage
occ_download_user_count(
user = NULL,
pwd = NULL,
from = NULL,
status = NULL,
curlopts = list(http_version = 2)
)Arguments
- user
(character) User name within GBIF's website. Required. See Details.
- pwd
(character) User password within GBIF's website. Required. See Details.
- from
(character) Optional. Start date in format
YYYY-MM-DD. Only downloads created on or after this date will be counted.- status
(character) Optional. Filter by download status. One of
"PREPARING","RUNNING","SUCCEEDED","CANCELLED","KILLED","FAILED","SUSPENDED", or"FILE_ERASED".- curlopts
list of named curl options passed on to
HttpClient. seecurl::curl_optionsfor curl options
Details
For user and pwd parameters, you can set them in one of three ways:
Set them in your
.Rprofilefile with the namesgbif_userandgbif_pwdSet them in your
.Renviron/.bash_profile(or similar) file with the namesGBIF_USERandGBIF_PWDSimply pass strings to each of the parameters in the function call
See ?Startup for help.