Learn R Programming

rgbif (version 0.7.7)

rgbif-package: Interface to the Global Biodiversity Information Facility API.

Description

rgbif: A programmatic interface to the Web Service methods provided by the Global Biodiversity Information Facility.

Arguments

About

This package gives you access to data from GBIF http://www.gbif.org/ via their API.

A note about the old GBIF API

If you still want to use the old GBIF API, described at http://data.gbif.org/tutorial/services let us know at https://github.com/ropensci/rgbif, or email Scott myrmecocystus@gmail.com

Documentation for the GBIF API

  • summaryhttp://www.gbif.org/developer/summary
  • registryhttp://www.gbif.org/developer/registry
  • species nameshttp://www.gbif.org/developer/species
  • occurrenceshttp://www.gbif.org/developer/occurrence
  • mapshttp://www.gbif.org/developer/maps